
function ImageTracker() {
	this.loadedImages = new Array();
	this.nowLoadingImages = new Array();
	this.thumbFileList = null;
	
	/*
	 * imgオブジェクトの画像が既に読み込まれている場合trueを返します。
	 *
	 * @param img
	 */
	this.checkLoaded = function(img) {
		var loaded = this.loadedImages[img.getAttribute("id")];
		
		return loaded;
	}
	
	/*
	 * 読込が完了した画像数を返します。
	 *
	 * @return
	 */
	this.getLoadedCount = function() {
		var cnt = 0;
		
		for(var i = 0; i < this.thumbFileList.length; i++) {
			if(this.loadedImages[this.thumbFileList[i].getName()])
				cnt += 1;
		}
		
		return cnt;
	}
	
	/*
	 * まだ読み込まれておらず、また現在読込を行っていない画像をFileオブジェクトを返します。
	 *
	 * @return file
	 */
	this.getNextImageFile = function() {
		var nextFile = null;
		
		for(var i = 0; i < this.thumbFileList.length; i++) {
			var file = this.thumbFileList[i];
			
			if(!this.loadedImages[file.getName()]
				&& !this.nowLoadingImages[file.getName()]) {
				nextFile = file;
				break;
			}
		}
		
		return nextFile;
	}
	
	/*
	 * 現在の読込状況をパーセンテージで返します。
	 *
	 * @return
	 */
	this.getStatus = function() {
		var loadedCnt = this.getLoadedCount();
		
		var status = loadedCnt / this.thumbFileList.length;
		status *= 100;
		status = parseInt(status);
		
		return status;
	}
	
	/*
	 * 全ての画像の読込が完了している場合trueを返します。
	 *
	 * @return
	 */
	this.isCompleted = function() {
		var completed = true;
		
		for(var i = 0; i < this.thumbFileList.length; i++) {
			var file = this.thumbFileList[i];
			
			if(!this.loadedImages[file.getName()]) {
				completed = false;
				break;
			}
		}
		
		return completed;
	}
	
	/*
	 * 読込が完了したことをトラッカーに通知します。
	 *
	 * @param img
	 */
	this.notifyCompleteLoading = function(img) {
		this.loadedImages[img.getAttribute("id")] = true;
		this.nowLoadingImages[img.getAttribute("id")] = false;
	}
	
	/*
	 * 読込を開始したことをトラッカーに通知します。
	 *
	 * @param file
	 */
	this.notifyStartLoading = function(file) {
		this.nowLoadingImages[file.getName()] = true;
	}
	
	/*
	 *
	 */
	this.setThumbFileList = function(fileList) {
		for(var i = 0; i < fileList.length; i++) {
			this.loadedImages[fileList[i].getName()] = false;
			this.nowLoadingImages[fileList[i].getName()] = false;
		}
		
		this.thumbFileList = fileList;
	}
	
}