//定数
const RECENT = "recent";

//変数
var cacheFile = null;
var mfLog = null;
var showingFile = null;
var showingRecordList = null;
var showingRecordDB = null;
var otherThreadRecordDB = {};
var winPost = null;
var imageBox = null;
var unvisibleRemovalNotification = false;

/**
 * 
 */
function closeImageBox(event) {
	imageBox.close(event);
}

/**
 * 
 */
function constructLogCombo() {
	var sel = document.getElementById("select_log");
	
	var nameList = mfLog.getNameOfLogFiles();
	
	var opt = document.createElement("option");
	opt.value = RECENT;
	opt.innerHTML = "Recent";
	sel.appendChild(opt);
	
	for(var i = 0; i < nameList.length; i++) {
		opt = document.createElement("option");
		opt.value = nameList[i];
		opt.innerHTML = "Log - " + String(i + 1);
		sel.appendChild(opt);
	}
}

/**
 * 
 */
function constructThread(recordList) {
	showingRecordDB = {};
	var unvisibleRemovalNotification = getPref("moonfox.thread.unvisible_removal_notification");
	var threadBox = document.getElementById("div_thread");
	var showRecord = null;
	
	for(var i = 0; i < recordList.length; i++) {
		if(recordList[i].isDeleted()
			|| (unvisibleRemovalNotification && recordList[i].isRemovalNotification()) )
			continue;
		
		var recElem = makeRecordElement(recordList[i]);
		threadBox.appendChild(recElem);
		showingRecordDB[recordList[i].id] = recordList[i];
		
		if( !recordList[0].unread && (!showRecord || !showRecord.unread) ) {
			showRecord = recordList[i];
		}
	}
	
	//新着、もしくは最新レスへジャンプ
	if(showRecord)
		self.location.hash = showRecord.id;
	
	//グローバル変数へ格納
	showingRecordList = recordList;
}

/**
 * 
 */
function dataLoadError() {
	showRecent();
	
	setMessage("Error occurred", "msg_error");
}

	
/**
 * 本スレッドを削除します。
 */
function deleteThread() {
	var ret = { ok:false};
	
	var thInfo = new ThreadInfo("");
	thInfo.file = cacheFile.file.getName();
	thInfo.title = cacheFile.title;
	thInfo.records = "";
	thInfo.size = "";
	
	var thInfoArray = [];
	thInfoArray.push(thInfo);
	
	window.openDialog("chrome://moonfox/content/delete/delete.xul"
		, "moonfox_delete"
		, "modal=yes,resizable=yes"
		, ret
		, thInfoArray);
	
	//
	if(ret.ok) {
		document.write("Probably deleted.");
		document.close();
	}
}

/**
 * ブロックID(ハッシュ値の左から8文字)からレコードを取得します。
 * @param {Object} blockId
 */
function getRecordFromBlockId(blockId) {
	var targetRecord = null;
	
	if(!showingRecordList)
		return;
	
	for(var i = 0; i < showingRecordList.length; i++) {
		var hash = showingRecordList[i].hash;
		
		if(hash.indexOf(blockId) >= 0) {
			targetRecord = showingRecordList[i];
			break;
		}
	}
	
	return targetRecord;
}

/**
 * チェックされたレスのＩＤを配列にして返します。
 */
function getSelectedRecordList() {
	var selectedRecordList = new Array();
	var checks = document.getElementsByTagName("input");
	
	for(var i = 0; i < checks.length; i++) {
		if(checks[i].type == "checkbox" && checks[i].checked && checks[i].id.match(/check\_([0-9]+\_[\w]+)/)) {
			var id = RegExp.$1;
			selectedRecordList.push(id);
		}
	}
	
	return selectedRecordList;
}


/**
 * 
 */
function removeAllRecordElement() {
	var threadBox = document.getElementById("div_thread");
	
	while(threadBox.firstChild) {
		threadBox.removeChild(threadBox.firstChild);
	}
}

/**
 * 
 * @param {Object} msg
 * @param {Object} cls
 */
function setMessage(msg, cls) {
	var msgObj = document.getElementById("div_msg");
	
	if(cls) {
		msgObj.className = cls;
	}
	
	msgObj.innerHTML = msg;
}

/**
 * 
 * @param {Object} title
 */
function setTitle(title) {
	window.document.title = cacheFile.title + " - Moonfox";
	document.getElementById("div_title").innerHTML = cacheFile.title;
}

/**
 * 全てのレスを表示します。
 */
function showAllRecord() {
	for(var i = 0; i < showingRecordList.length; i++) {
		var dl = document.getElementById(showingRecordList[i].id);
		
		if(dl)
			dl.style.display = "block"
	}
}

/**
 * チェックされたレスのみを表示します。
 */
function showCheckedRecordOnly() {
	var threadBox = document.getElementById("div_thread");
	var checks = threadBox.getElementsByTagName("input");
	var cnt = 0;
	
	for(var i = 0; i < checks.length; i++) {
		if(!checks[i].checked && checks[i].id.match(/check\_([0-9]+\_[\w]+)/)) {
			var id = RegExp.$1;
			
			document.getElementById(id).style.display = "none";
		} else {
			cnt += 1;
		}
	}
	
	return cnt;
}

/**
 * 
 * @param {Object} event
 * @param {Object} url
 */
function showImageBox(event, url) {
	if(!event || !url)
		return;
	
	imageBox.show(event, url);
}



/**
 * 
 */
function showPastLog() {
	var sel = document.getElementById("select_log");
	var opt = sel.options[sel.selectedIndex];
	var val = opt.value;
	
	if(val == RECENT) {
		showRecent();
	} else {
		var doc = mfLog.getPastLogAsDoc(val);
		var recordList = docToRecordList(doc);
		removeAllRecordElement();
		constructThread(recordList);
		showingFile = val;
		setMessage("Done.", "msg");
		
		//削除フォームを隠す
		document.getElementById("div_deleteform").style.display = "none";
	}
}

/**
 * 直近のレコードを表示します。
 */
function showRecent() {
	var doc = mfLog.getRecentLogAsDoc();
	var recordList = docToRecordList(doc);
	var last = null;
	if(recordList && recordList.length > 0)
		last = recordList[recordList.length - 1];
	
	var newRecList = cacheFile.getNewRecordList(doc, last);
	
	//表示するレコードがない場合
	if( (!recordList || recordList.length == 0)
			&& (!newRecList || newRecList.length == 0) ) {
		setMessage("No record.", "msg");
		return;
	}
	
	recordList = recordList.concat(newRecList);
	
	removeAllRecordElement();	
	constructThread(recordList);
	showingFile = RECENT;
	
	//ログに保存
	mfLog.saveRecentLog(recordList);
	var postHist = new PostHistory(mfLog.threadName);
	postHist.append(newRecList);
	
	setMessage("Done.", "msg");
	
	//コンボを設定
	var sel = document.getElementById("select_log");
	sel.selectedIndex = 0;
	
	//削除フォームを隠す
	document.getElementById("div_deleteform").style.display = "none";
}

/**
 * 指定記事をポップアップで表示します。
 * @param {Object} record
 */
function showReferedRecord(event, record, otherThread) {
	var elem = null;
	
	if(!record)
		return elem;
	
	var recBox = new RecordBox(event, record, otherThread);
	recBox.show();
}
